CCL: /home/chisarie/Documents/lsst_ccl/CCL/include/ccl_neutrinos.h File Reference

CCL

Macros | Functions
ccl_neutrinos.h File Reference
`#include "ccl_core.h"`
`#include "gsl/gsl_spline.h"`
`#include "gsl/gsl_const_mksa.h"`

Go to the source code of this file.

## Macros
#define | CCL_MAX_NU_SPECIES 3
#define | CCL_NU_MNUT_MIN 1e-4
#define | CCL_NU_MNUT_MAX 500
#define | CCL_NU_MNUT_N 1000
#define | NU_CONST (8. * pow(M_PI,5) *pow((KBOLTZ/ HPLANCK),3)* KBOLTZ/(15. *pow( CLIGHT,3))* (8. * M_PI * GNEWT) / (3. * 100.*100.*1000.*1000. /MPC_TO_METER /MPC_TO_METER * CLIGHT * CLIGHT))

## Functions
gsl_spline * | calculate_nu_phasespace_spline (int *status)
double | Omeganuh2 (double a, double Neff, double mnu, double TCMB, gsl_interp_accel *accel, int *status)

## Macro Definition Documentation

## ◆ CCL_MAX_NU_SPECIES

#define CCL_MAX_NU_SPECIES 3

## ◆ CCL_NU_MNUT_MAX

#define CCL_NU_MNUT_MAX 500

## ◆ CCL_NU_MNUT_MIN

#define CCL_NU_MNUT_MIN 1e-4

## ◆ CCL_NU_MNUT_N

#define CCL_NU_MNUT_N 1000

## ◆ NU_CONST

#define NU_CONST (8. * pow(M_PI,5) *pow((KBOLTZ/ HPLANCK),3)* KBOLTZ/(15. *pow( CLIGHT,3))* (8. * M_PI * GNEWT) / (3. * 100.*100.*1000.*1000. /MPC_TO_METER /MPC_TO_METER * CLIGHT * CLIGHT))

## Function Documentation

## ◆ calculate_nu_phasespace_spline()

gsl_spline* calculate_nu_phasespace_spline | ( | int * | status | ) |

Spline for the phasespace integral required for getting the fractional energy density of massive neutrinos. Returns a gsl spline for the phase space integral needed for massive neutrinos.

Parameters

  status | Status flag. 0 if there are no errors, nonzero otherwise. For specific cases see documentation for ccl_error.c

Returns
  spl, the gsl spline for the phasespace integral required for massive neutrino calculations.

## ◆ Omeganuh2()

double Omeganuh2 | ( | double | a,
|  | double | Neff,
|  | double | mnu,
|  | double | TCMB,
|  | gsl_interp_accel * | accel,
|  | int * | status
| ) |  |

Returns density of one neutrino species at a scale factor a. Users are encouraged to access this quantity via the function ccl_omega_x.

Parameters

  a | Scale factor
  Neff | The effective number of species with neutrino mass mnu.
  mnu | Neutrino mass (can be 0).
  TCMB | Temperature of the CMB
  accel | - Interpolation accelerator to be used with phasespace spline. If not set yet, pass NULL.
  status | Status flag. 0 if there are no errors, nonzero otherwise. For specific cases see documentation for ccl_error.c

Returns
  OmNuh2 Fractional energy density of neutrions with mass mnu, multiplied by h squared.